@@ -27,7 +27,6 @@
 #endif
 
 #include "eog-error-message-area.h"
-#include "eog-message-area.h"
 #include "eog-image.h"
 
 #include <glib.h>
@@ -36,10 +35,10 @@
 #include <gtk/gtk.h>
 
 static void
-set_message_area_text_and_icon (EogMessageArea   *message_area,
-				const gchar      *icon_stock_id,
-				const gchar      *primary_text,
-				const gchar      *secondary_text)
+set_message_area_text_and_icon (GtkInfoBar   *message_area,
+				const gchar  *icon_stock_id,
+				const gchar  *primary_text,
+				const gchar  *secondary_text)
 {
 	GtkWidget *hbox_content;
 	GtkWidget *image;
@@ -72,7 +71,7 @@ set_message_area_text_and_icon (EogMessageArea   *message_area,
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), FALSE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
 
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
@@ -86,7 +85,7 @@ set_message_area_text_and_icon (EogMessageArea   *message_area,
 
 		gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
 
-		GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (secondary_label, TRUE);
 
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
@@ -94,8 +93,7 @@ set_message_area_text_and_icon (EogMessageArea   *message_area,
 		gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
 	}
 
-	eog_message_area_set_contents (EOG_MESSAGE_AREA (message_area),
-				       hbox_content);
+	gtk_box_pack_start (GTK_BOX (gtk_info_bar_get_content_area (GTK_INFO_BAR (message_area))), hbox_content, TRUE, TRUE, 0);
 }
 
 static GtkWidget *
@@ -106,13 +104,16 @@ create_error_message_area (const gchar *primary_text,
 	GtkWidget *message_area;
 
 	if (recoverable)
-		message_area = eog_message_area_new_with_buttons (
-						_("_Retry"), GTK_RESPONSE_OK,
-						NULL);
+		message_area = gtk_info_bar_new_with_buttons (_("_Retry"),
+							      GTK_RESPONSE_OK,
+							      NULL);
 	else
-		message_area = eog_message_area_new ();
+		message_area = gtk_info_bar_new ();
 
-	set_message_area_text_and_icon (EOG_MESSAGE_AREA (message_area),
+	gtk_info_bar_set_message_type (GTK_INFO_BAR (message_area),
+				       GTK_MESSAGE_ERROR);
+
+	set_message_area_text_and_icon (GTK_INFO_BAR (message_area),
 					GTK_STOCK_DIALOG_ERROR,
 					primary_text,
 					secondary_text);
